@@ -5,7 +5,7 @@ use warnings;
 
 use MooX::ReturnModifiers;
 use B;
-our $VERSION = '1.012008';
+our $VERSION = '1.012009';
 
 sub import {
 	my $target	= caller;
@@ -15,7 +15,7 @@ sub import {
 		my ($error, $c) = @_;
 		if (ref $error) {
 			my $gv = B::svref_2object($c)->GV;
-			$error->{context}->{file} = $gv->FILE;
+			$error->{context}->{file} = $gv->FILE . '::' . $gv->NAME;
 			$error->{context}->{line} = $gv->LINE;
 		}
 		die $error;
@@ -92,7 +92,7 @@ MooX::ValidateSubs - Validating sub routines via Type::Tiny.
 
 =head1 VERSION
 
-Version 1.012008
+Version 1.012009
 
 =cut
 
